summaryrefslogtreecommitdiff
path: root/backport_others.sh
diff options
context:
space:
mode:
Diffstat (limited to 'backport_others.sh')
-rw-r--r--backport_others.sh18
1 files changed, 11 insertions, 7 deletions
diff --git a/backport_others.sh b/backport_others.sh
index dc74564..c154318 100644
--- a/backport_others.sh
+++ b/backport_others.sh
@@ -4,6 +4,7 @@
# sudo -E ./backport_others.sh
# Preconditions: - shell variables DIST and ARCH
+# - pbuilder chroot set up (see README)
# - current R backport in /etc/apt/sources/list of pbuilder chroot
# - sid sources in /etc/apt/sources/list
# - ssed and cdbs installed (and maybe more)
@@ -20,20 +21,23 @@ echo Architecture is $ARCH
text="Recompiled on $DIST for CRAN"
rbasedev="r-base-dev (>= $Rversion~$DIST$reposversion.0)"
-echo $rbasedev
-#apt-get update
+# Update the Package listings of the host system
+apt-get update
+# Update the pbuilder chroot
pbuilder update
+# When doing a new repository, lattice, r-cran-mass and survival have to be
+# built first, then nlme and rmatrix, then the rest
+
# single package:
-for i in boot; do
-# lenny packages:
-#for i in boot cluster codetools foreign kernsmooth lattice mgcv nlme r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rmatrix rodbc rpart survival littler; do
+for i in r-cran-coda; do
# squeeze/wheezy packages:
#for i in boot cluster codetools foreign kernsmooth lattice mgcv nlme r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rmatrix rodbc rpart survival littler rpy rkward; do
apt-get source $i
cd $i-*
- version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~$DIST"cran".$Rversion
+ version=`dpkg-parsechangelog | grep ^Version | cut -f2 -d " "`~$DIST"cran3.0"
dch -b -v $version --force-distribution -D $DIST-$reposversion $text
ssed -i -R "/^Build-Depends/s/r-base-dev \(>= .*?\)/$rbasedev/" debian/control
@@ -20,20 +21,23 @@ echo Architecture is $ARCH
# squeeze/wheezy packages:
-#for i in boot cluster codetools foreign kernsmooth lattice mgcv nlme r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rmatrix rodbc rpart survival littler rpy rkward; do
+#for i in mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
+#for i in lattice nlme rmatrix mgcv boot cluster codetools foreign kernsmooth r-cran-class r-cran-coda r-cran-spatial r-cran-nnet r-cran-mass rodbc rpart survival littler rpy rpy2 rkward; do
apt-get source $i
cd $i-*

Contact - Imprint